PackageUtils class

Constructors

PackageUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appName String
The app name. CFBundleDisplayName on iOS, application/label on Android.
no setter
buildNumber String
The build number. CFBundleVersion on iOS, versionCode on Android.
no setter
buildSignature String
The build signature. Empty string on iOS, signing key signature (hex) on Android.
no setter
packageName String
The package name. bundleIdentifier on iOS, getPackageName on Android.
no setter
version String
The package version. CFBundleShortVersionString on iOS, versionName on Android.
no setter

Static Methods

initPackageInfo() Future
在使用之前必须初始化