RectangleSwiperIndicator class

矩形指示器

Implemented types

Constructors

RectangleSwiperIndicator({EdgeInsetsGeometry? padding, double spacing = 4.0, double itemWidth = 16.0, double itemHeight = 2.0, Color itemColor = Colors.white70, Color? itemActiveColor})

Properties

hashCode int
The hash code for this object.
no setterinherited
itemActiveColor Color?
finalinherited
itemColor Color
finalinherited
itemHeight double
finalinherited
itemShape BoxShape
finalinherited
itemWidth double
finalinherited
padding EdgeInsetsGeometry?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
finalinherited

Methods

build(BuildContext context, int index, int itemCount) Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited