SwiperController class

Inheritance

Constructors

SwiperController({int initialPage = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
index int
当前滚动的位置
no setter
initialPage int
初始化要展示的位置
final
offset double?
当前的偏移量
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
animateToPage(int page, {required Duration duration, required Curve curve}) Future<void>
切换到某个位置
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
nextPage({required Duration duration, required Curve curve}) Future<void>
下一页
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
previousPage({required Duration duration, required Curve curve}) Future<void>
上一页
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
start() → void
开始滚动
stop() → void
停止滚动
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited