Swiper class

Inheritance

Constructors

Swiper({Key? key, Axis direction = Axis.horizontal, bool autoStart = true, SwiperController? controller, SwiperIndicator? indicator, int speed = 300, Duration interval = const Duration(seconds: 3), bool circular = true, bool reverse = false, AlignmentDirectional indicatorAlignment = AlignmentDirectional.bottomCenter, double viewportFraction = 1.0, ValueChanged<int>? onChanged, ValueChanged<int>? onTap, required List<Widget>? children})
Swiper.builder({Key? key, Axis direction = Axis.horizontal, required int childCount, required IndexedWidgetBuilder itemBuilder, bool autoStart = true, SwiperController? controller, SwiperIndicator? indicator, int speed = 300, Duration interval = const Duration(seconds: 3), bool circular = true, bool reverse = false, AlignmentDirectional indicatorAlignment = AlignmentDirectional.bottomCenter, double viewportFraction = 1.0, ValueChanged<int>? onChanged, ValueChanged<int>? onTap})
const

Properties

autoStart bool
是否自动开始轮播
final
childCount int
轮播页面的数量
final
children List<Widget>?
final
circular bool
是否循环播放
final
controller SwiperController?
final
direction Axis
滚动方向
final
hashCode int
The hash code for this object.
no setterinherited
indicator SwiperIndicator?
指示器
final
indicatorAlignment AlignmentDirectional
指示器位置
final
interval Duration
页面切换时间间隔
final
itemBuilder IndexedWidgetBuilder
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged ValueChanged<int>?
页面切换回调
final
onTap ValueChanged<int>?
点击某个页面
final
reverse bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed int
轮播切换速度
final
viewportFraction double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _SwiperState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited